pub trait OpentsdbProtocolHandler {
// Required methods
fn preflight<'life0, 'life1, 'async_trait>(
&'life0 self,
data_points: &'life1 [DataPoint],
ctx: QueryContextRef,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn exec<'life0, 'async_trait>(
&'life0 self,
data_points: Vec<DataPoint>,
ctx: QueryContextRef,
) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Required Methods
Sourcefn preflight<'life0, 'life1, 'async_trait>(
&'life0 self,
data_points: &'life1 [DataPoint],
ctx: QueryContextRef,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn preflight<'life0, 'life1, 'async_trait>(
&'life0 self,
data_points: &'life1 [DataPoint],
ctx: QueryContextRef,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Checks all points in one external request before per-point debug execution.
Sourcefn exec<'life0, 'async_trait>(
&'life0 self,
data_points: Vec<DataPoint>,
ctx: QueryContextRef,
) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn exec<'life0, 'async_trait>(
&'life0 self,
data_points: Vec<DataPoint>,
ctx: QueryContextRef,
) -> Pin<Box<dyn Future<Output = Result<usize>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
A successful request will not return a response. Only on error will the socket return a line of data.